@@ -1,10 +1,10 @@
 use strict;
 use warnings;
 
-use v5.6.0;
+use v5.010;
 
 package WebService::SmartRow;
-
+$WebService::SmartRow::VERSION = '0.005';
 # ABSTRACT: Connect and get data from SmartRow API
 
 use HTTP::Tiny;
@@ -23,6 +23,26 @@ has http => (
     },
 );
 
+
+# https://smartrow.fit/api/challenge
+sub get_challenges {
+    my $self = shift;
+
+    my ( $user, $pass ) = $self->_credentials_via_env;
+
+    my $response = $self->http->request( 'GET',
+        'https://' . $user . ':' . $pass . '@' . 'smartrow.fit/api/challenge' );
+
+    if ( !$response->{success} ) {
+        return 'Response error';
+    }
+
+    my $json = decode_json $response->{content};
+
+    return $json;
+}
+
+
 # https://smartrow.fit/api/account
 sub get_profile {
     my $self = shift;
@@ -43,6 +63,24 @@ sub get_profile {
 
 # https://smartrow.fit/api/public-game
 sub get_workouts {
+    my $self = shift;
+
+    my ( $user, $pass ) = $self->_credentials_via_env;
+
+    my $response = $self->http->request( 'GET',
+              'https://'
+            . $user . ':'
+            . $pass . '@'
+            . 'smartrow.fit/api/public-game'
+            );
+
+    if ( !$response->{success} ) {
+        return 'Response error';
+    }
+
+    my $json = decode_json $response->{content};
+
+    return $json;
 }
 
 sub get_leaderboard {
@@ -86,12 +124,6 @@ sub _credentials_via_env {
 }
 
 
-
-
-
-
-
-
 1;
 
 __END__
@@ -106,9 +138,11 @@ WebService::SmartRow - Connect and get data from SmartRow API
 
 =head1 VERSION
 
-version 0.004
+version 0.005
 
- This module is a basic wrapper to allow Perl apps to access data from https://smartrow.fit
+=head1 SYNOPSIS
+
+This module is a basic wrapper to allow Perl apps to access data from https://smartrow.fit
 
  my $smartrow = WebService::SmartRow->new(
   username => 'foo',
@@ -118,62 +152,66 @@ version 0.004
  my $profile  = $smartrow->get_profile;
  my $workouts = $smartrow->get_workouts;
 
- Credentials can be passed via environment variables
+Credentials can be passed via environment variables
 
- * SMARTROW_USERNAME
- * SMARTROW_PASSWORD
+* SMARTROW_USERNAME
+* SMARTROW_PASSWORD
 
- If passing credentials via ENV you can simply use WebService::SmartRow->new;
+If passing credentials via ENV you can simply use WebService::SmartRow->new;
 
 =head1 ATTRIBUTES
 
 =head2 http
 
-  http is a HTTP::Tiny object by default, you can provide your own on construction.
+http is a HTTP::Tiny object by default, you can provide your own on construction.
 
-  This might be helpful if, for example, you wanted to change the user agent.
+This might be helpful if, for example, you wanted to change the user agent.
 
 =head2 username
 
-  get/set the username for the API
+get/set the username for the API
 
-  Note that we parse the username in get_ methods to escape the "@" char.
+Note that we parse the username in get_ methods to escape the "@" char.
 
-  You can also set the SMARTROW_USERNAME environment variable.
+You can also set the SMARTROW_USERNAME environment variable.
 
 =head2 password
 
-  get/set the password for the API
+get/set the password for the API
 
-  You can also set the SMARTROW_PASSWORD environment variable.
+You can also set the SMARTROW_PASSWORD environment variable.
 
 =head1 METHODS
 
 =head2 get_profile
 
-  This method obtains your profile information
+This method obtains your profile information
 
 =head2 get_workouts
 
-  This method returns all the workouts you have done via SmartRow
+This method returns all the workouts you have done via SmartRow
 
 =head2 get_leaderboard
 
-  This method returns the data presented in the leaderboard (AKA Rankings page).
+This method returns the data presented in the leaderboard (AKA Rankings page).
 
-  Unlike the first two methods, get_leaderboard can accept parameters to limit the data.
+Unlike the first two methods, get_leaderboard can accept parameters to limit the data.
 
-  e.g.
-       my $leaderboard = $srv->get_leaderboard(
-           distance => 5000,  # Default if not provided to 2000, is mandatory
-           year     => 2022,
-           country  => 188,
-           age      => 'c',
-           gender   => 'f',
-           weight   => 'l',
-       );
+e.g.
+    my $leaderboard = $srv->get_leaderboard(
+         distance => 5000,  # If not provided will default to 2000
+         year     => 2022,
+         country  => 188,
+         age      => 'c',
+         gender   => 'f',   # m or f (male or female)
+         weight   => 'l',   # l or h (light or heavy)
+     );
 
-   More details on values able to be used to follow.
+More details on values able to be used to follow.
+
+=head2 get_challenges
+
+This method returns an array of challenges, there are no parameters.
 
 =head1 AUTHOR
 
